@@ -18,6 +18,7 @@
 #' @param speciesList A character vector. Should contain species names as they appear in the 
 #' speciesColumn to make maps of. User can also specify "ALL" in order to make maps of all 
 #' species present in the data. Hence, a user may first filter their data and then use "ALL".
+#' Default = "ALL".
 #' @param countryList A character vector. Country names to map, or NULL for to map ALL countries.
 #' @param jitterValue Numeric. The amount, in decimal degrees, to jitter the map points by - this 
 #' is important for separating stacked points with the same coordinates.
@@ -26,22 +27,25 @@
 #' @param overWrite Logical. If TRUE, the function will overwrite existing files in the provided
 #' directory that have the same name.
 #' Default = TRUE.
+#' @param customColumn1 Character. Allows the user to report on a column of their choosing in the output.
+#' @param customColumn2 Character. Allows the user to report on a column of their choosing in the output.
 #' @param TrueAlwaysTop If TRUE, the quality (TRUE) points will always be displayed on top of other points. 
 #' If FALSE, then whichever layer was turned on most-recently will be displayed on top.
-#' @param excludeApis_mellifera Logical. If TRUE, will not map records for Apis mellifera. Note: in most cases 
-#' A. mellifera has too many points, and the resulting map will take a long time to make and be difficult to open.
-#' Default = TRUE.
+#' @param excludeSpecies Character. A character vector of species names to exclude, especially
+#' if they are so large as to become a problem when making maps. For bee data, for example, 
+#' "Apis mellifera Linnaeus, 1758" has too many data points and is default excluded. 
 #' @param pointColours A character vector of colours. In order provide colour for TRUE, FALSE, countryOutlier, and customOutlier.
 #' Default = c("blue", "darkred","#ff7f00", "black").
+#' @param returnPlot Logical. If TRUE, return the plot to the environment. Default = FALSE.
+#' 
 #'
 #' @return Exports .html interactive maps of bee occurrences to the specified directory.
 #' @export
 #' 
 #' @importFrom dplyr %>%
-#' @importFrom dplyr across
+#' @importFrom dplyr across where
 #'
 #' @examples
-#' if(requireNamespace("leaflet")){
 #' OutPath_Figures <- tempdir()
 #' 
 #' interactiveMapR(
@@ -68,12 +72,11 @@
 #' # If TRUE, it will only map the .summary column. Otherwise, it will map .summary
 #' # which will be over-written by countryOutliers and manualOutliers
 #' onlySummary = TRUE,
-#' excludeApis_mellifera = TRUE,
+#' excludeSpecies = c("Apis mellifera Linnaeus, 1758"),
 #' overWrite = TRUE,
 #'   # Colours for points which are flagged as TRUE, FALSE, countryOutlier, and customOutlier
 #' pointColours = c("blue", "darkred","#ff7f00", "black")
 #' )
-#' } # END if require
 
 interactiveMapR <- function(
       # occurrence data
@@ -86,14 +89,17 @@ interactiveMapR <- function(
       # Occurrence dataset column with species names
     speciesColumn = "scientificName",
       # Which species to map - a character vector of names or "ALL"
-    speciesList = NULL,
+    speciesList = "ALL",
     countryList = NULL,
     jitterValue = NULL,
     onlySummary = TRUE,
     overWrite = TRUE,
+    customColumn1 = NULL,
+    customColumn2 = NULL,
     TrueAlwaysTop = FALSE,
-    excludeApis_mellifera = TRUE,
-    pointColours = c("blue", "darkred","#ff7f00", "black")
+    excludeSpecies = c("Apis mellifera Linnaeus, 1758"),
+    pointColours = c("blue", "darkred","#ff7f00", "black"),
+    returnPlot = FALSE
     ){
   # locally bind variables to the function
   country <- .data <- scientificName <- expertOutlier <- .countryOutlier <- .summary <-
@@ -119,6 +125,32 @@ interactiveMapR <- function(
   if(is.null(outPath)){
     stop(paste0(" - No outPath was given. Please specify the directory to save the maps to."))
   }
+    #customColumn1
+  if(!is.null(customColumn1)){
+    if(!is.character(customColumn1)){
+      stop(paste0(" - customColumn1 must be character."))
+    }
+    if(!customColumn1 %in% colnames(data)){
+      stop(paste0(" - customColumn1 must be a column in the input data"))
+    }
+    # Temporarily rename the customColumn1 to "customColumn1" within the function
+    data <- data %>%
+      dplyr::rename("customColumn1" = tidyselect::any_of(customColumn1))
+    
+  } # END customColumn1
+  #customColumn2
+  if(!is.null(customColumn2)){
+    if(!is.character(customColumn2)){
+      stop(paste0(" - customColumn2 must be character."))
+    }
+    if(!customColumn2 %in% colnames(data)){
+      stop(paste0(" - customColumn2 must be a column in the input data"))
+    }
+    # Temporarily rename the customColumn2 to "customColumn2" within the function
+    data <- data %>%
+      dplyr::rename("customColumn2" = tidyselect::any_of(customColumn2))
+  } # END customColumn2
+  
   
   ##### 0.2 Packages ####
   # Save the original directory 
@@ -134,49 +166,6 @@ setwd(outPath) #directory of work
 
   # data$IDall <- paste0(1:nrow(data)) #to add an ID by row
 
-  
-
-##### 0.4 leaflet test ####
-###### a. test ####
-# Check if leaflet is installed
-# TRUE if leaflet is found
-suppressWarnings(
-  suggestedTest <- system.file(package='leaflet') %>% 
-    stringr::str_count() > 0 
-)
-
-###### b. leaflet ####
-if(suggestedTest == FALSE){
-  # Set up instructions for download on fail
-  instructions <- paste(" Please try installing the package for yourself", 
-                        "using the following command: \n",
-                        "install.packages(\"leaflet\")")
-  # Set up fail function for tryCatch
-  error_func <- function(e){
-    stop(paste("Failed to install the leaflet package.\n", 
-               instructions))
-  }
-  # Begin interactive input
-  input <- 1
-  if (interactive()){
-    input <- utils::menu(c("Yes", "No"), 
-                         title = paste0("Install the leaflet package? \n"))
-  }
-  if(input == 1){
-    # Start leaflet install
-    message("Installing the leaflet package.")
-    tryCatch(
-      utils::install.packages("leaflet"), 
-      error = error_func, warning = error_func)
-  } # END input == 1
-  
-  else{
-    stop(writeLines(paste("The leaflet package is necessary for BeeBDC::interactiveMapR.\n", 
-                          instructions)))
-  } # END else
-} # END suggestedTest == FALSE
-
-
   #### 1.0 Data prep ####
     ##### 1.1 Remove na+ ####
 data <- data %>%
@@ -196,6 +185,20 @@ if(!".expertOutlier" %in% colnames(data)){
   data <- data %>% 
     dplyr::mutate(.expertOutlier = TRUE)
 }
+# If there is no .countryOutlier then add one as all NA
+if(!".countryOutlier" %in% colnames(data)){
+  message("The column .countryOutlier was not found. One will be created with all values = TRUE.")
+  data <- data %>% 
+    dplyr::mutate(.countryOutlier = TRUE)
+}
+# If there is no .summary then add one as all NA
+if(!".summary" %in% colnames(data)){
+  message("The column .summary was not found. One will be created with all values = TRUE.")
+  data <- data %>% 
+    dplyr::mutate(.summary = TRUE)
+}
+
+
 
 ##### 1.2 Country list ####
 # Select only the countries user provides
@@ -216,10 +219,10 @@ if(any(stringr::str_detect(speciesList, "ALL")) == FALSE){
 
 
 ##### 1.4 excludeApis_mellifera ####
-if(excludeApis_mellifera == TRUE){
+if(!is.null(excludeSpecies)){
   data <- data %>%
-    dplyr::filter(!scientificName == "Apis mellifera Linnaeus, 1758")
-  speciesList <- setdiff(speciesList, "Apis mellifera Linnaeus, 1758")
+    dplyr::filter(!scientificName %in% excludeSpecies )
+  speciesList <- setdiff(speciesList, excludeSpecies)
 }
 
 
@@ -291,7 +294,7 @@ speciesList <- speciesList[complete.cases(speciesList)]
 
 options(encoding = "UTF-8")
 
-data <- data %>% dplyr::mutate(dplyr::across(tidyselect::where(is.character), 
+data <- data %>% dplyr::mutate(dplyr::across(where(is.character), 
                               function(x){iconv(x, 
                                                 to = "UTF-8",
                                                 sub = "")}))
@@ -484,6 +487,18 @@ for(i in 1:length(names(databaseLoop))){
                                          ";   ")},
                                 if("references" %in% colnames(databaseSpp)){
                                   paste0("References: ", databaseSpp$references, 
+                                         "   ")},
+                                
+                                # Custom column reporting
+                                if(!is.null(customColumn1)|!is.null(customColumn2)){
+                                  "<p></p><b>Custom column(s)</b> - "
+                                },
+                              
+                                if(!is.null(customColumn1)){
+                                  paste0(customColumn1, ": ", databaseSpp$customColumn1, 
+                                         "   ")},
+                                if(!is.null(customColumn2)){
+                                  paste0(customColumn2, ": ", databaseSpp$customColumn2, 
                                          "   ")}
    
                                 
@@ -540,6 +555,10 @@ for(i in 1:length(names(databaseLoop))){
 # reset to original directory
 setwd(olddir)
 
+if(returnPlot == TRUE){
+return(mdatabaseSpp)
+}
+
 } # END function
 
 
