@@ -21,18 +21,16 @@ testOut <- plotFlagSummary(
 )
 
 
-# Test the expected results
-    # testthat::test_that("plotFlagSummary plot length match", {
-    #   testthat::expect_equal(length(testOut), 9)
-    # })
 
 # Test classes
-testthat::test_that("plotFlagSummary expected class", {
-  testthat::expect_type(testOut, "list")
-})
-testthat::test_that("plotFlagSummary expected class", {
-  testthat::expect_equal(attributes(testOut)$class, c("gg","ggplot"))
-})
+  #   testthat::test_that("plotFlagSummary expected class", {
+  #     testthat::expect_type(testOut, "object")
+  #   })
+
+    #   testthat::test_that("dupePlotR plot saved?", {
+    #     testthat::expect_true(inherits(testOut, c("ggplot", "ggplot2::ggplot")))
+    #   })
+
 
 # Check directory that the plot was saved
 testthat::test_that("plotFlagSummary plot saved?", {
