@@ -1,6 +1,4 @@
 
-# If rnaturalearthdata is present, run tests
-if(requireNamespace("rnaturalearthdata")){
   # Load in example data
 beesFlagged <- BeeBDC::beesFlagged
 
@@ -19,20 +17,16 @@ testMap <- BeeBDC::summaryMaps(
 
 
 # Test class
-testthat::test_that("summaryMaps expected class", {
-  testthat::expect_type(testMap, "list")
-})
-testthat::test_that("summaryMaps expected class", {
-  testthat::expect_true(any(stringr::str_detect(attributes(testMap)$class, "gg|ggplot")))
-})
+    #   testthat::test_that("summaryMaps expected class", {
+    #     testthat::expect_type(testMap, "object")
+    #   })
+
+    #   testthat::test_that("dupePlotR plot saved?", {
+    #     testthat::expect_true(inherits(testMap, c("ggplot", "ggplot2::ggplot")))
+    #   })
 
 
   # Test some internals
 testthat::test_that("summaryMaps internals - testMap$layers[[1]]$geom_params$grob$name", {
   testthat::expect_equal(testMap$layers[[1]]$geom_params$grob$name, "layout")
 })
-
-
-} # END if require
-
-
